<?php

/*-----------------------------------------------------------------------------
# 関数名 : request_prefix
# 因  数 :
# 戻り値 :
# 説  明 : 表示された現在のファイルのPREFIX（「.../index.php」の場合「index」）を返す
-----------------------------------------------------------------------------*/
function request_prefix()
{
    $target_url = $_SERVER["REQUEST_URI"];
    $pos = strrpos($target_url, "/");
    $fname = substr($target_url, $pos + 1);

    if (!$fname) {
        $fname = "index.php";
    }

    $pos = strpos($fname, ".");
    return substr($fname, 0, $pos);
}

/*-----------------------------------------------------------------------------
# 関数名 : get_viewfile
# 因  数 :
# 戻り値 :
# 説  明 : ソースファイルと同じ名前のVIEWファイルを呼び出す
-----------------------------------------------------------------------------*/
function get_viewfile()
{
    $reftgt = _WU_ROOT . "/view/" . request_prefix() . ".view";

    //SOURCEファイルと同じディレクトリのVIEWファイルを返す
    return ($reftgt);
}


/*-----------------------------------------------------------------------------
# 関数名 : html_header
# 因  数 :
# 戻り値 :
# 説  明 : 全ページ共通のHTMLヘッダ
-----------------------------------------------------------------------------*/
function html_header()
{
    global $ERROR;
?>
<!DOCTYPE html>
<html lang="ja">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta name="viewport" content="width=device-width, user-scalable=no, initial-scale=1, maximum-scale=1">
<title><?=_WU_SITE_NAME?></title>
<link rel="stylesheet" href="./css/avafitui.css" />
</head>

<body>
<?php /* 各viewファイルに記入するように変更 2011-06-09 kohashi */ ?>
<? /*=error_view($ERROR);*/ ?>

<?php
    // WebKitブラウザ以外では見られないようにする。
    if( !(is_entry()) ){
?>
<section class="article_b text-16" style="background:#CC0000;color:#FFFFFF;text-align:center;line-height:2em;font-weight:bold;">
    <div>非対応</div>
</section>
<section class="article_b text-16">
    <div style="font-weight:bold;">ご利用の環境では、AVAFIT FLASHスマートフォン版対応サンプルをご覧になれません。</div>
    <ul style="border:none;margin-top:0px;margin-bottom:-20px;padding:0;">
        <li style="color:#000000;border:none;">【対応環境】</li>
    </ul>
    <ul>
        <li>Android OS標準搭載のブラウザ</li>
        <li>iOS(iPhone、iPad、iPod touch)標準搭載のSafariブラウザ</li>
        <li>SafariまたはGoogle ChromeブラウザをインストールしたPC(Windows、MacOSX、Linux)</li>
    </ul>
</section>
<div class="clearfix"></div>
<?php
    html_footer();
    exit;
    }
?>

<?php
}

/*-----------------------------------------------------------------------------
# 関数名 : html_footer
# 因  数 :
# 戻り値 :
# 説  明 : 全ページ共通のHTMLフッダ
-----------------------------------------------------------------------------*/
function html_footer()
{

?>
<?php if( (is_entry()) ){ ?>
<!-- Go To TOP -->
<section id="foot_select">
    <ul class="navi">
        <li><a href="<?=_WU_RETURN_URL?>">TOPページ</a></li>
    </ul>
</section>
<div class="spacer"></div>
<!-- Go To TOP -->
<?php } ?>


<!-- FOOTER -->
<footer id="footer">
    <div id="credit">
        (C)<?=date("Y")?> <?=_WU_SITE_NAME?>
    </div>
</footer>

</body>


</html>
<?php
}

/*-----------------------------------------------------------------------------
# 関数名 : error_view
# 因  数 :
# 説  明 : エラーメッセージを表示
-----------------------------------------------------------------------------*/
function error_view($err_array)
{
    if (!sizeof($err_array)) {
        return false;
    }

    $exist = false;

    $rtn  = null;
    $rtn .= "<div class='article_b text-14'>\n";
    $rtn .= "<span style='color:#FF0000;'>\n";
    for ($i = 0; $i < sizeof($err_array); $i++) {
        if ($err_array[$i]) {
            $rtn .= "!".$err_array[$i]."<BR>\n";
            $exist = true;
        }
    }
    $rtn .= "</span>\n";
    $rtn .= "</div>\n";
    $rtn .= "<div class='clearfix'></div>\n";

    if ($exist) {
        return $rtn;
    }
    else {
        return "";
    }
}

/*-----------------------------------------------------------------------------
# 関数名 : form_select
# 因  数 : $key_name     : SELECTの変数名
#          $selected     : 選択されるように表示すべき値
#          $array        : SELECT内に表示する配列（必ず、KEY/NAMEフィールドを使う）
# 説  明 : 選択ボックスを表示する
-----------------------------------------------------------------------------*/
function form_select($keyname, $selected, $array)
{
    if (!$keyname) {
        return false;
    }
    if (sizeof($array) <= 0) {
        $err_exp = "<span style='color:#FF0000;'>:未登録</span>";
        return $err_exp;
    }

    $rtn  = "<SELECT NAME='$keyname'>\n";
    $rtn .= "<OPTION VALUE='0'>【全て】</OPTION>\n";

    for ($i = 0; $i < sizeof($array); $i++) {
        if ($selected && $array[$i]["KEY"] == $selected) {
            $sel_val = "selected";
        }
        else {
            $sel_val = "";
        }
        $rtn .= "<OPTION $css VALUE='".$array[$i]["KEY"]."' $sel_val>".$array[$i]["NAME"]."</OPTION>\n";
    }

    $rtn .= "</SELECT>\n";

    return $rtn;
}

/*-----------------------------------------------------------------------------
# 関数名 : paging
# 因  数 : $record_cnt        : レコード件数
#          $offset            : 現在のレコード位置
#          $one_pg_record_num : 1ページあたりのレコード数
#          $opt_param         : 付随のパラメーター
# 説  明 : 一覧ページのページング処理を行う
-----------------------------------------------------------------------------*/
function paging($record_cnt, $offset_name, $offset, $one_pg_record_num, $opt_param)
{
    // 20100125 k global_registers=off 対策として $_SERVER['PHP_SELF']を使用

    //表示されるページ番号数(前へ 1 2 3 4 5 -> 13 次へ)
    $page_cnt_in_block = 5;

    //ページ当りアイテム表示数
    if (!$one_pg_record_num) {
        $one_pg_record_num = _WU_ITEM_CNT_LIST_PAGE;
    }

    //現在のページを求める
    $page = ceil(($offset + 1) / $one_pg_record_num);

    //現在BLOCKの最初offset
    $curr_block_first = intval($offset / ($page_cnt_in_block * $one_pg_record_num)) * ($page_cnt_in_block * $one_pg_record_num);

    //前・次のBLOCK
    $prev_block = $curr_block_first - ($page_cnt_in_block * $one_pg_record_num);
    if ($prev_block < 0) {
        $prev_block = 0;
    }

    $next_block = $curr_block_first + ($page_cnt_in_block * $one_pg_record_num);

    //全ページ数
    $total_page = ceil($record_cnt / $one_pg_record_num);
    if (!$page) {
        $page = 1;
    }
    $page_list = ceil($page / $page_cnt_in_block) - 1;

    //現在が13ページ目の場合は10ページ以前は 「1 ... 11 12 ･･･」形式で表示する
    if ($page_list > 0) {
        $nav_str .= "<a href='".$_SERVER['PHP_SELF']."?$offset_name=0&$opt_param'>1</a> . \n";
        $offset = $prev_block;
        $nav_str .= "<a href='".$_SERVER['PHP_SELF']."?$offset_name=$offset&$opt_param'>←</a> \n";
    }

    $page_end = ($page_list + 1) * $page_cnt_in_block;

    if ($page_end > $total_page) {
        $page_end = $total_page;
    }

    for ($setpage = $page_list * $page_cnt_in_block + 1; $setpage <= $page_end; $setpage++)
    {
        if ($setpage == $page) {
            $nav_str .= "$setpage \n";
        }
        else{
            $offset = ($setpage-1) * $one_pg_record_num;
            $nav_str .= "<a href='".$_SERVER['PHP_SELF']."?$offset_name=$offset&$opt_param'>$setpage</a> \n";
        }
    }

    if ($page_end < $total_page)
    {
        $offset = $next_block;
        $nav_str .= "<a href='".$_SERVER['PHP_SELF']."?$offset_name=$offset&$opt_param'>→</a> \n";
        $offset = ($total_page - 1) * $one_pg_record_num;
        $nav_str .= ". <a href='".$_SERVER['PHP_SELF']."?$offset_name=$offset&$opt_param'>$total_page</a>\n";
    }

    return $nav_str;
}

/*-----------------------------------------------------------------------------
# 関数名 : pager
# 因  数 : $record_cnt        : レコード件数
#          $offset            : 現在のレコード位置
#          $one_pg_record_num : 1ページあたりのレコード数
#          $opt_param         : 付随のパラメーター
# 説  明 : 一覧ページで、[前へ] [次へ]リンク形式のページング処理を行う
-----------------------------------------------------------------------------*/
function pager($record_cnt, $offset_name, $offset, $one_pg_record_num, $opt_param)
{
    //表示されるページ番号数
    //→[前へ] [次へ]リンクのみの場合は「1」で。
    $page_cnt_in_block = 1;

    //ページ当りアイテム表示数
    if (!$one_pg_record_num) {
        $one_pg_record_num = _WU_ITEM_CNT_LIST_PAGE;
    }

    //現在のページを求める
    $page = ceil(($offset + 1) / $one_pg_record_num);

    //現在BLOCKの最初offset
    $curr_block_first = intval($offset / ($page_cnt_in_block * $one_pg_record_num)) * ($page_cnt_in_block * $one_pg_record_num);

    //前・次のBLOCK
    $prev_block = $curr_block_first - ($page_cnt_in_block * $one_pg_record_num);
    if ($prev_block < 0) {
        $prev_block = 0;
    }

    $next_block = $curr_block_first + ($page_cnt_in_block * $one_pg_record_num);

    //全ページ数
    $total_page = ceil($record_cnt / $one_pg_record_num);
    if (!$page) {
        $page = 1;
    }
    $page_list = ceil($page / $page_cnt_in_block) - 1;

    //全Xページ中・Yページ目である場合は「[＊]前へ (Y/X) [＃]次へ」形式で表示する
    $nav_str = null;
    if ($page_list > 0) {
        $offset = $prev_block;
        $nav_str .= "<a href='".$_SERVER['PHP_SELF']."?$offset_name=$offset&$opt_param' accesskey='*'>←[*]前へ</a> \n";
    }else{
        $nav_str .= "&nbsp;&nbsp;[*]前へ";
    }

    $page_end = ($page_list + 1) * $page_cnt_in_block;

    if ($page_end > $total_page) {
        $page_end = $total_page;
    }

    $nav_str .= "&nbsp;&nbsp;(".$page."/".$total_page.")&nbsp;&nbsp;";

    if ($page_end < $total_page)
    {
        $offset = $next_block;
        $nav_str .= "<a href='".$_SERVER['PHP_SELF']."?$offset_name=$offset&$opt_param' accesskey='#'>次へ[#]→</a> \n";
    }else{
        $nav_str .= "次へ[#]&nbsp;&nbsp;";
    }

    return $nav_str;
}

/*-----------------------------------------------------------------------------
# 関数名 : validate_number
# 因  数 :
# 戻り値 :
# 説  明 : 入力された数字の有効性をチェックする
-----------------------------------------------------------------------------*/
function validate_number( $num )
{
    //[0]から[9]までの数字及びマイナス(-)記号まで対応
    //マイナス(-)を入れない場合は「^[0-9]+$」にする
    if(ereg('^[0-9\-]+$', $num, $err))
    {
        return(true);
    }
    else
    {
        return(false);
    }
}

/* -----------------------------------------------------------------------------
# 関数名：スマートフォン識別（iPhone, iPodTouch, Android）
# 正式名：is_smartphone
# 因　数：
# 返却値：1/0
# 説　明：ユーザエージェントを元に、スマートフォン（以下の対象機種）かを判別
# 　　　　対象：iPhone, iPodTouch, iPad, Android
----------------------------------------------------------------------------- */
function is_smartphone(){

    //タブレットであるiPadも含めておく。
    $agents = array(
        'iPhone',  // iPhone
        'iPod',    // iPod touch
        'iPad',    // iPad
        'Android' // Android
    );
    $pattern = '/'.implode('|', $agents).'/i';
    $agent_check = preg_match($pattern, $_SERVER['HTTP_USER_AGENT']);

    // trueなら1を返す
    return ($agent_check ) ? 1 : 0;

}


/* -----------------------------------------------------------------------------
# 関数名：Apple iOS識別（iPhone, iPodTouch, iPad）
# 正式名：is_ios
# 因　数：
# 返却値：1/0
# 説　明：ユーザエージェントを元に、Apple iOS採用デバイス（以下の対象機種）かを判別
# 　　　　対象：iPhone, iPodTouch, iPad
# 　　　　※WebKit使用ブラウザ判定は行わない。
----------------------------------------------------------------------------- */
function is_ios(){
    // Apple iOS採用デバイス(iPhone, iPodTouch, iPad)にはFLASHが搭載されていないため、
    // FLASHの代わりに静止画の表示が必要になる。
    // よって、ユーザエージェントで該当デバイスかを、この関数で判定する。
    $agents = array(
        'iPhone',  // iPhone
        'iPod',    // iPod touch
        'iPad',    // iPad
    );
    $pattern = '/'.implode('|', $agents).'/i';
    $agent_check = preg_match($pattern, $_SERVER['HTTP_USER_AGENT']);

    // 双方がtrueなら1を返す
    return ($agent_check) ? 1 : 0;

}


/* -----------------------------------------------------------------------------
# 関数名：WebKit識別（iPhone, iPodTouch, Android）
# 正式名：is_webkit
# 因　数：
# 返却値：1/0
# 説　明：ユーザエージェントを元に、WebKit使用ブラウザかを判別。
----------------------------------------------------------------------------- */
function is_webkit(){

    // ユーザエージェントに「AppleWebKit」の記述があるか確認
    $pattern = '/AppleWebKit/i';
    $agent_check = preg_match($pattern, $_SERVER['HTTP_USER_AGENT']);

    // trueなら1を返す
    return ($agent_check) ? 1 : 0;

}


/* -----------------------------------------------------------------------------
# 関数名：UI使用可能を識別（iPhone, iPodTouch, Android）
# 正式名：is_entry
# 因　数：
# 返却値：1/0
# 説　明：ユーザエージェントを元に、WebKit使用ブラウザかを判別。
----------------------------------------------------------------------------- */
function is_entry(){

    // スマートフォン判別
    $sp_flag = 1;
    //if( !(is_webkit()) || !(is_smartphone()) ){
    if( !(is_webkit()) ){
        $sp_flag = 0; // 非該当の場合
    }

    return $sp_flag;
}


/* -----------------------------------------------------------------------------
# 関数名：スマートフォン対応（iPhone, iPodTouch, Android）
# 正式名：is_smartphone
# 因　数：$params (Shift_JIS)
# 返却値：$params (UTF-8)
# 説　明：APIから取得したデータをSJISからUTF8に変換
# ※スマートフォン用UIではHTML5/CSS3を使うため、HTML上の文字コードはUTF-8にする。
# 　しかしAVAFIT Proでは、Shift_JISで値を返すため、UI側でUTF-8に変換する必要がある。
----------------------------------------------------------------------------- */
function get_sp($params){
    mb_convert_variables("UTF-8","Shift_JIS",$params);
    return $params;
}


/* -----------------------------------------------------------------------------
# 関数名：スマートフォン対応（iPhone, iPodTouch, Android）
# 正式名：put_record_for_sp
# 因　数：$params (Shift_JIS)
# 返却値：$params (UTF-8)
# 説　明：APIへデータを渡す前にUTF8からSJISに変換
# ※上記とは逆の動き。
# 　スマートフォン用UIで入力された値は、UTF-8からShift_JISに変換する必要がある。
----------------------------------------------------------------------------- */
function put_sp($params){
    mb_convert_variables("Shift_JIS","UTF-8",$params);
    return $params;
}


/*-----------------------------------------------------------------------------
# 関数名 : pager
# 因  数 : $record_cnt        : レコード件数
#          $offset            : 現在のレコード位置
#          $one_pg_record_num : 1ページあたりのレコード数
#          $opt_param         : 付随のパラメーター
# 説  明 : 一覧ページで、[前へ] [次へ]リンク形式のページング処理を行う
-----------------------------------------------------------------------------*/
function pager_sp($record_cnt, $offset_name, $offset, $one_pg_record_num, $opt_param)
{
    // global_registers=off 対策として $_SERVER['PHP_SELF']を使用

    //表示されるページ番号数
    //→[前へ] [次へ]リンクのみの場合は「1」で。
    $page_cnt_in_block = 1;

    //ページ当りアイテム表示数
    if (!$one_pg_record_num) {
        $one_pg_record_num = _WU_ITEM_CNT_LIST_PAGE;
    }

    //現在のページを求める
    $page = ceil(($offset + 1) / $one_pg_record_num);

    //現在BLOCKの最初offset
    $curr_block_first = intval($offset / ($page_cnt_in_block * $one_pg_record_num)) * ($page_cnt_in_block * $one_pg_record_num);

    //前・次のBLOCK
    $prev_block = $curr_block_first - ($page_cnt_in_block * $one_pg_record_num);
    if ($prev_block < 0) {
        $prev_block = 0;
    }

    $next_block = $curr_block_first + ($page_cnt_in_block * $one_pg_record_num);

    //全ページ数
    $total_page = ceil($record_cnt / $one_pg_record_num);
    if (!$page) {
        $page = 1;
    }
    $page_list = ceil($page / $page_cnt_in_block) - 1;

    //全Xページ中・Yページ目である場合は「[＊]前へ (Y/X) [＃]次へ」形式で表示する
    // スマートフォン用に最適化 2011-06-09 k
    $nav_str = null;
    $nav_str .="<ul class='pager_sp'>\n";
    if ($page_list > 0) {
        $offset = $prev_block;
        $nav_str .= "<li class='pager_bk'><a href='".$_SERVER['PHP_SELF']."?$offset_name=$offset&$opt_param'>前へ</a></li>\n";
    }else{
        $nav_str .= "<li class='pager_bk_not'>前へ</li>";
    }

    $page_end = ($page_list + 1) * $page_cnt_in_block;

    if ($page_end > $total_page) {
        $page_end = $total_page;
    }

    $nav_str .= "<li class='pager_center'>".$page."/".$total_page."</li>";

    if ($page_end < $total_page)
    {
        $offset = $next_block;
        $nav_str .= "<li class='pager_fw'><a href='".$_SERVER['PHP_SELF']."?$offset_name=$offset&$opt_param'>次へ</a></li>\n";
    }else{
        $nav_str .= "<li class='pager_fw_not'>次へ</li>";
    }
    $nav_str .="</ul>\n";

    return $nav_str;
}


?>